[Catalyst-commits] r12734 - Catalyst-View-Email/trunk/lib/Catalyst/View

dhoss at dev.catalyst.perl.org dhoss at dev.catalyst.perl.org
Wed Jan 27 09:07:21 GMT 2010


Author: dhoss
Date: 2010-01-27 09:07:21 +0000 (Wed, 27 Jan 2010)
New Revision: 12734

Modified:
   Catalyst-View-Email/trunk/lib/Catalyst/View/Email.pm
Log:
HAHAHA wow unfucked find/replace of Email::Send shit

Modified: Catalyst-View-Email/trunk/lib/Catalyst/View/Email.pm
===================================================================
--- Catalyst-View-Email/trunk/lib/Catalyst/View/Email.pm	2010-01-27 09:04:47 UTC (rev 12733)
+++ Catalyst-View-Email/trunk/lib/Catalyst/View/Email.pm	2010-01-27 09:07:21 UTC (rev 12734)
@@ -4,7 +4,7 @@
 use Carp;
 
 use Encode qw(encode decode);
-use Email::Sender::Simpleer::Simple qw/ sendmail /;
+use Email::Sender::Simple qw/ sendmail /;
 use Email::MIME::Creator;
 extends 'Catalyst::View';
 
@@ -19,7 +19,7 @@
 
 has '_mailer_obj' => (
     is      => 'rw',
-    isa     => 'Email::Sender::Simpleer::Transport',
+    isa     => 'Email::Sender::Transport',
     lazy    => 1,
     builder => '_build_mailer_obj',
 );
@@ -94,12 +94,12 @@
                 charset => 'utf-8'
             },
             # Setup how to send the email
             # all those options are passed directly to Email::Sender::Simple
             sender => {
-                # if mailer doesn't start with Email::Sender::Simpleer::Transport::,
+                # if mailer doesn't start with Email::Sender::Transport::,
                 # then this is prepended.
                 mailer => 'SMTP',
                 # mailer_args is passed directly into Email::Sender::Simple 
                 mailer_args => {
                     host     => 'smtp.example.com', # defaults to localhost
                     username => 'username',
@@ -191,7 +191,7 @@
 
 =item new
 
-Validates the base config and creates the L<Email::Sender::Simple> object for later use
+Validates the base config and creates the L<Email::Send> object for later use
 by process.
 
 =cut
@@ -209,9 +209,9 @@
   my ($self) = @_;
   my $transport_class = ucfirst $self->sender->{mailer};
 
-  # borrowed from Email::Sender::Simpleer::Simple -- apeiron, 2010-01-26 
-  if ($transport_class !~ /^Email::Sender::Simpleer::Transport::/) {
-    $transport_class = "Email::Sender::Simpleer::Transport::$transport_class";
+  # borrowed from Email::Sender::Simple -- apeiron, 2010-01-26 
+  if ($transport_class !~ /^Email::Sender::Transport::/) {
+    $transport_class = "Email::Sender::Transport::$transport_class";
   }
 
   Class::MOP::load_class($transport_class);
@@ -223,7 +223,7 @@
 
 The process method does the actual processing when the view is dispatched to.
 
-This method sets up the email parts and hands off to L<Email::Sender::Simple> to handle
+This method sets up the email parts and hands off to L<Email::Send> to handle
 the actual email delivery.
 
 =cut
@@ -371,7 +371,7 @@
 As with most things computer related, things break.  Email even more so.  
 Typically any errors are going to come from using SMTP as your sending method,
 which means that if you are having trouble the first place to look is at
-L<Email::Sender::Simple::SMTP>.  This module is just a wrapper for L<Email::Sender::Simple>,
+L<Email::Send::SMTP>.  This module is just a wrapper for L<Email::Send>,
 so if you get an error on sending, it is likely from there anyway.
 
 If you are using SMTP and have troubles sending, whether it is authentication
@@ -94,12 +94,12 @@
             },
             # Setup how to send the email
-            # all those options are passed directly to Email::Sender::Simple
+            # all those options are passed directly to Email::Send
             sender => {
@@ -94,12 +94,12 @@
                 # then this is prepended.
                 mailer => 'SMTP',
-                # mailer_args is passed directly into Email::Sender::Simple 
+                # mailer_args is passed directly into Email::Send 
                 mailer_args => {
                     host     => 'smtp.example.com', # defaults to localhost




More information about the Catalyst-commits mailing list